/* acconfig.h for BEAST - Bedevilled Audio System
 * here we list all symbols, which get introduced by configure.in
 */

#include "PKG_paths.h"

@TOP@

#undef  BST_ARCH_NAME
#undef  BST_VERSION
#undef  BST_VERSION_HINT
#undef  BST_DFL_KEYTABLE
#undef  BST_WITH_XKB
#undef  BST_WITH_GDK_PIXBUF
#undef  BSE_PCM_DEVICE_CONF_ALSA
#undef  BSE_PCM_DEVICE_CONF_OSS

@BOTTOM@
